@@ -1,3 +1,5 @@
+from .barycentric_triangle import barycentric_triangle_weights
+from .barycentric_wachspress import barycentric_wachspress_weights
 from .cohen_sutherland import cohen_sutherland_line_box_clip
 from .cyrus_beck import cyrus_beck_line_polygon_clip
 from .liang_barsky import liang_barsky_line_box_clip
